# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class WebTest(pulumi.CustomResource):
    application_insights_id: pulumi.Output[str]
    """
    The ID of the Application Insights component on which the WebTest operates. Changing this forces a new resource to be created.
    """
    configuration: pulumi.Output[str]
    """
    An XML configuration specification for a WebTest.
    """
    description: pulumi.Output[str]
    """
    Purpose/user defined descriptive test for this WebTest.
    """
    enabled: pulumi.Output[bool]
    """
    Is the test actively being monitored.
    """
    frequency: pulumi.Output[float]
    """
    Interval in seconds between test runs for this WebTest. Default is `300`.
    """
    geo_locations: pulumi.Output[list]
    """
    A list of where to physically run the tests from to give global coverage for accessibility of your application.
    """
    kind: pulumi.Output[str]
    """
    = (Required) The kind of web test that this web test watches. Choices are `ping` and `multistep`.
    """
    location: pulumi.Output[str]
    """
    The location of the resource group.
    """
    name: pulumi.Output[str]
    """
    Specifies the name of the Application Insights WebTest. Changing this forces a
    new resource to be created.
    """
    resource_group_name: pulumi.Output[str]
    retry_enabled: pulumi.Output[bool]
    """
    Allow for retries should this WebTest fail.
    """
    synthetic_monitor_id: pulumi.Output[str]
    tags: pulumi.Output[dict]
    """
    Resource tags.
    """
    timeout: pulumi.Output[float]
    """
    Seconds until this WebTest will timeout and fail. Default is `30`.
    """
    def __init__(__self__, resource_name, opts=None, application_insights_id=None, configuration=None, description=None, enabled=None, frequency=None, geo_locations=None, kind=None, location=None, name=None, resource_group_name=None, retry_enabled=None, tags=None, timeout=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Application Insights WebTest.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_insights_id: The ID of the Application Insights component on which the WebTest operates. Changing this forces a new resource to be created.
        :param pulumi.Input[str] configuration: An XML configuration specification for a WebTest.
        :param pulumi.Input[str] description: Purpose/user defined descriptive test for this WebTest.
        :param pulumi.Input[bool] enabled: Is the test actively being monitored.
        :param pulumi.Input[float] frequency: Interval in seconds between test runs for this WebTest. Default is `300`.
        :param pulumi.Input[list] geo_locations: A list of where to physically run the tests from to give global coverage for accessibility of your application.
        :param pulumi.Input[str] kind: = (Required) The kind of web test that this web test watches. Choices are `ping` and `multistep`.
        :param pulumi.Input[str] location: The location of the resource group.
        :param pulumi.Input[str] name: Specifies the name of the Application Insights WebTest. Changing this forces a
               new resource to be created.
        :param pulumi.Input[bool] retry_enabled: Allow for retries should this WebTest fail.
        :param pulumi.Input[dict] tags: Resource tags.
        :param pulumi.Input[float] timeout: Seconds until this WebTest will timeout and fail. Default is `30`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if application_insights_id is None:
                raise TypeError("Missing required property 'application_insights_id'")
            __props__['application_insights_id'] = application_insights_id
            if configuration is None:
                raise TypeError("Missing required property 'configuration'")
            __props__['configuration'] = configuration
            __props__['description'] = description
            __props__['enabled'] = enabled
            __props__['frequency'] = frequency
            if geo_locations is None:
                raise TypeError("Missing required property 'geo_locations'")
            __props__['geo_locations'] = geo_locations
            if kind is None:
                raise TypeError("Missing required property 'kind'")
            __props__['kind'] = kind
            __props__['location'] = location
            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['retry_enabled'] = retry_enabled
            __props__['tags'] = tags
            __props__['timeout'] = timeout
            __props__['synthetic_monitor_id'] = None
        super(WebTest, __self__).__init__(
            'azure:appinsights/webTest:WebTest',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, application_insights_id=None, configuration=None, description=None, enabled=None, frequency=None, geo_locations=None, kind=None, location=None, name=None, resource_group_name=None, retry_enabled=None, synthetic_monitor_id=None, tags=None, timeout=None):
        """
        Get an existing WebTest resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_insights_id: The ID of the Application Insights component on which the WebTest operates. Changing this forces a new resource to be created.
        :param pulumi.Input[str] configuration: An XML configuration specification for a WebTest.
        :param pulumi.Input[str] description: Purpose/user defined descriptive test for this WebTest.
        :param pulumi.Input[bool] enabled: Is the test actively being monitored.
        :param pulumi.Input[float] frequency: Interval in seconds between test runs for this WebTest. Default is `300`.
        :param pulumi.Input[list] geo_locations: A list of where to physically run the tests from to give global coverage for accessibility of your application.
        :param pulumi.Input[str] kind: = (Required) The kind of web test that this web test watches. Choices are `ping` and `multistep`.
        :param pulumi.Input[str] location: The location of the resource group.
        :param pulumi.Input[str] name: Specifies the name of the Application Insights WebTest. Changing this forces a
               new resource to be created.
        :param pulumi.Input[bool] retry_enabled: Allow for retries should this WebTest fail.
        :param pulumi.Input[dict] tags: Resource tags.
        :param pulumi.Input[float] timeout: Seconds until this WebTest will timeout and fail. Default is `30`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["application_insights_id"] = application_insights_id
        __props__["configuration"] = configuration
        __props__["description"] = description
        __props__["enabled"] = enabled
        __props__["frequency"] = frequency
        __props__["geo_locations"] = geo_locations
        __props__["kind"] = kind
        __props__["location"] = location
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["retry_enabled"] = retry_enabled
        __props__["synthetic_monitor_id"] = synthetic_monitor_id
        __props__["tags"] = tags
        __props__["timeout"] = timeout
        return WebTest(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .a_record import *
from .aaaa_record import *
from .cname_record import *
from .get_dns_zone import *
from .link_service import *
from .mx_record import *
from .ptr_record import *
from .srv_record import *
from .txt_record import *
from .zone import *
from .zone_virtual_network_link import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetServiceResult:
    """
    A collection of values returned by getService.
    """
    def __init__(__self__, additional_locations=None, developer_portal_url=None, gateway_regional_url=None, gateway_url=None, hostname_configurations=None, id=None, identities=None, location=None, management_api_url=None, name=None, notification_sender_email=None, portal_url=None, public_ip_addresses=None, publisher_email=None, publisher_name=None, resource_group_name=None, scm_url=None, sku_name=None, tags=None):
        if additional_locations and not isinstance(additional_locations, list):
            raise TypeError("Expected argument 'additional_locations' to be a list")
        __self__.additional_locations = additional_locations
        """
        One or more `additional_location` blocks as defined below
        """
        if developer_portal_url and not isinstance(developer_portal_url, str):
            raise TypeError("Expected argument 'developer_portal_url' to be a str")
        __self__.developer_portal_url = developer_portal_url
        """
        The URL for the Developer Portal associated with this API Management service.
        """
        if gateway_regional_url and not isinstance(gateway_regional_url, str):
            raise TypeError("Expected argument 'gateway_regional_url' to be a str")
        __self__.gateway_regional_url = gateway_regional_url
        """
        Gateway URL of the API Management service in the Region.
        """
        if gateway_url and not isinstance(gateway_url, str):
            raise TypeError("Expected argument 'gateway_url' to be a str")
        __self__.gateway_url = gateway_url
        """
        The URL for the API Management Service's Gateway.
        """
        if hostname_configurations and not isinstance(hostname_configurations, list):
            raise TypeError("Expected argument 'hostname_configurations' to be a list")
        __self__.hostname_configurations = hostname_configurations
        """
        A `hostname_configuration` block as defined below.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if identities and not isinstance(identities, list):
            raise TypeError("Expected argument 'identities' to be a list")
        __self__.identities = identities
        """
        (Optional) An `identity` block as defined below.
        """
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        __self__.location = location
        """
        The location name of the additional region among Azure Data center regions.
        """
        if management_api_url and not isinstance(management_api_url, str):
            raise TypeError("Expected argument 'management_api_url' to be a str")
        __self__.management_api_url = management_api_url
        """
        The URL for the Management API.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        Specifies the plan's pricing tier.
        """
        if notification_sender_email and not isinstance(notification_sender_email, str):
            raise TypeError("Expected argument 'notification_sender_email' to be a str")
        __self__.notification_sender_email = notification_sender_email
        """
        The email address from which the notification will be sent.
        """
        if portal_url and not isinstance(portal_url, str):
            raise TypeError("Expected argument 'portal_url' to be a str")
        __self__.portal_url = portal_url
        """
        The URL of the Publisher Portal.
        """
        if public_ip_addresses and not isinstance(public_ip_addresses, list):
            raise TypeError("Expected argument 'public_ip_addresses' to be a list")
        __self__.public_ip_addresses = public_ip_addresses
        """
        Public Static Load Balanced IP addresses of the API Management service in the additional location. Available only for Basic, Standard and Premium SKU.
        """
        if publisher_email and not isinstance(publisher_email, str):
            raise TypeError("Expected argument 'publisher_email' to be a str")
        __self__.publisher_email = publisher_email
        """
        The email of Publisher/Company of the API Management Service.
        """
        if publisher_name and not isinstance(publisher_name, str):
            raise TypeError("Expected argument 'publisher_name' to be a str")
        __self__.publisher_name = publisher_name
        """
        The name of the Publisher/Company of the API Management Service.
        """
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        __self__.resource_group_name = resource_group_name
        if scm_url and not isinstance(scm_url, str):
            raise TypeError("Expected argument 'scm_url' to be a str")
        __self__.scm_url = scm_url
        """
        The SCM (Source Code Management) endpoint.
        """
        if sku_name and not isinstance(sku_name, str):
            raise TypeError("Expected argument 'sku_name' to be a str")
        __self__.sku_name = sku_name
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        """
        A mapping of tags assigned to the resource.
        """
class AwaitableGetServiceResult(GetServiceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceResult(
            additional_locations=self.additional_locations,
            developer_portal_url=self.developer_portal_url,
            gateway_regional_url=self.gateway_regional_url,
            gateway_url=self.gateway_url,
            hostname_configurations=self.hostname_configurations,
            id=self.id,
            identities=self.identities,
            location=self.location,
            management_api_url=self.management_api_url,
            name=self.name,
            notification_sender_email=self.notification_sender_email,
            portal_url=self.portal_url,
            public_ip_addresses=self.public_ip_addresses,
            publisher_email=self.publisher_email,
            publisher_name=self.publisher_name,
            resource_group_name=self.resource_group_name,
            scm_url=self.scm_url,
            sku_name=self.sku_name,
            tags=self.tags)

def get_service(name=None,resource_group_name=None,opts=None):
    """
    Use this data source to access information about an existing API Management Service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.apimanagement.get_service(name="search-api",
        resource_group_name="search-service")
    pulumi.export("apiManagementId", example.id)
    ```


    :param str name: The name of the API Management service.
    :param str resource_group_name: The Name of the Resource Group in which the API Management Service exists.
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:apimanagement/getService:getService', __args__, opts=opts).value

    return AwaitableGetServiceResult(
        additional_locations=__ret__.get('additionalLocations'),
        developer_portal_url=__ret__.get('developerPortalUrl'),
        gateway_regional_url=__ret__.get('gatewayRegionalUrl'),
        gateway_url=__ret__.get('gatewayUrl'),
        hostname_configurations=__ret__.get('hostnameConfigurations'),
        id=__ret__.get('id'),
        identities=__ret__.get('identities'),
        location=__ret__.get('location'),
        management_api_url=__ret__.get('managementApiUrl'),
        name=__ret__.get('name'),
        notification_sender_email=__ret__.get('notificationSenderEmail'),
        portal_url=__ret__.get('portalUrl'),
        public_ip_addresses=__ret__.get('publicIpAddresses'),
        publisher_email=__ret__.get('publisherEmail'),
        publisher_name=__ret__.get('publisherName'),
        resource_group_name=__ret__.get('resourceGroupName'),
        scm_url=__ret__.get('scmUrl'),
        sku_name=__ret__.get('skuName'),
        tags=__ret__.get('tags'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class Configuration(pulumi.CustomResource):
    name: pulumi.Output[str]
    """
    Specifies the name of the PostgreSQL Configuration, which needs [to be a valid PostgreSQL configuration name](https://www.postgresql.org/docs/current/static/sql-syntax-lexical.html#SQL-SYNTAX-IDENTIFIER). Changing this forces a new resource to be created.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which the PostgreSQL Server exists. Changing this forces a new resource to be created.
    """
    server_name: pulumi.Output[str]
    """
    Specifies the name of the PostgreSQL Server. Changing this forces a new resource to be created.
    """
    value: pulumi.Output[str]
    """
    Specifies the value of the PostgreSQL Configuration. See the PostgreSQL documentation for valid values.
    """
    def __init__(__self__, resource_name, opts=None, name=None, resource_group_name=None, server_name=None, value=None, __props__=None, __name__=None, __opts__=None):
        """
        Sets a PostgreSQL Configuration value on a PostgreSQL Server.

        ## Disclaimers

        > **Note:** Since this resource is provisioned by default, the Azure Provider will not check for the presence of an existing resource prior to attempting to create it.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_server = azure.postgresql.Server("exampleServer",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            sku_name="B_Gen5_2",
            storage_mb=5120,
            backup_retention_days=7,
            geo_redundant_backup_enabled=False,
            auto_grow_enabled=True,
            administrator_login="psqladminun",
            administrator_login_password="H@Sh1CoR3!",
            version="9.5",
            ssl_enforcement_enabled=True)
        example_configuration = azure.postgresql.Configuration("exampleConfiguration",
            resource_group_name=example_resource_group.name,
            server_name=example_server.name,
            value="on")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Specifies the name of the PostgreSQL Configuration, which needs [to be a valid PostgreSQL configuration name](https://www.postgresql.org/docs/current/static/sql-syntax-lexical.html#SQL-SYNTAX-IDENTIFIER). Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the PostgreSQL Server exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] server_name: Specifies the name of the PostgreSQL Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] value: Specifies the value of the PostgreSQL Configuration. See the PostgreSQL documentation for valid values.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if server_name is None:
                raise TypeError("Missing required property 'server_name'")
            __props__['server_name'] = server_name
            if value is None:
                raise TypeError("Missing required property 'value'")
            __props__['value'] = value
        super(Configuration, __self__).__init__(
            'azure:postgresql/configuration:Configuration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, name=None, resource_group_name=None, server_name=None, value=None):
        """
        Get an existing Configuration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Specifies the name of the PostgreSQL Configuration, which needs [to be a valid PostgreSQL configuration name](https://www.postgresql.org/docs/current/static/sql-syntax-lexical.html#SQL-SYNTAX-IDENTIFIER). Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the PostgreSQL Server exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] server_name: Specifies the name of the PostgreSQL Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] value: Specifies the value of the PostgreSQL Configuration. See the PostgreSQL documentation for valid values.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["server_name"] = server_name
        __props__["value"] = value
        return Configuration(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class AssignmentVirtualMachine(pulumi.CustomResource):
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    maintenance_configuration_id: pulumi.Output[str]
    """
    Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
    """
    virtual_machine_id: pulumi.Output[str]
    """
    Specifies the Virtual Machine ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, location=None, maintenance_configuration_id=None, virtual_machine_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a maintenance assignment to virtual machine.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("exampleVirtualNetwork",
            address_spaces=["10.0.0.0/16"],
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_subnet = azure.network.Subnet("exampleSubnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefix="10.0.2.0/24")
        example_network_interface = azure.network.NetworkInterface("exampleNetworkInterface",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            ip_configurations=[{
                "name": "internal",
                "subnet_id": example_subnet.id,
                "privateIpAddressAllocation": "Dynamic",
            }])
        example_linux_virtual_machine = azure.compute.LinuxVirtualMachine("exampleLinuxVirtualMachine",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            size="Standard_F2",
            admin_username="adminuser",
            network_interface_ids=[example_network_interface.id],
            admin_ssh_keys=[{
                "username": "adminuser",
                "publicKey": (lambda path: open(path).read())("~/.ssh/id_rsa.pub"),
            }],
            os_disk={
                "caching": "ReadWrite",
                "storage_account_type": "Standard_LRS",
            },
            source_image_reference={
                "publisher": "Canonical",
                "offer": "UbuntuServer",
                "sku": "16.04-LTS",
                "version": "latest",
            })
        example_configuration = azure.maintenance.Configuration("exampleConfiguration",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            scope="All")
        example_assignment_virtual_machine = azure.maintenance.AssignmentVirtualMachine("exampleAssignmentVirtualMachine",
            location=example_resource_group.location,
            maintenance_configuration_id=example_configuration.id,
            virtual_machine_id=example_linux_virtual_machine.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] virtual_machine_id: Specifies the Virtual Machine ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['location'] = location
            if maintenance_configuration_id is None:
                raise TypeError("Missing required property 'maintenance_configuration_id'")
            __props__['maintenance_configuration_id'] = maintenance_configuration_id
            if virtual_machine_id is None:
                raise TypeError("Missing required property 'virtual_machine_id'")
            __props__['virtual_machine_id'] = virtual_machine_id
        super(AssignmentVirtualMachine, __self__).__init__(
            'azure:maintenance/assignmentVirtualMachine:AssignmentVirtualMachine',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, location=None, maintenance_configuration_id=None, virtual_machine_id=None):
        """
        Get an existing AssignmentVirtualMachine resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] virtual_machine_id: Specifies the Virtual Machine ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["location"] = location
        __props__["maintenance_configuration_id"] = maintenance_configuration_id
        __props__["virtual_machine_id"] = virtual_machine_id
        return AssignmentVirtualMachine(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetRecommendationsResult:
    """
    A collection of values returned by getRecommendations.
    """
    def __init__(__self__, filter_by_categories=None, filter_by_resource_groups=None, id=None, recommendations=None):
        if filter_by_categories and not isinstance(filter_by_categories, list):
            raise TypeError("Expected argument 'filter_by_categories' to be a list")
        __self__.filter_by_categories = filter_by_categories
        if filter_by_resource_groups and not isinstance(filter_by_resource_groups, list):
            raise TypeError("Expected argument 'filter_by_resource_groups' to be a list")
        __self__.filter_by_resource_groups = filter_by_resource_groups
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if recommendations and not isinstance(recommendations, list):
            raise TypeError("Expected argument 'recommendations' to be a list")
        __self__.recommendations = recommendations
        """
        One or more `recommendations` blocks as defined below.
        """
class AwaitableGetRecommendationsResult(GetRecommendationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRecommendationsResult(
            filter_by_categories=self.filter_by_categories,
            filter_by_resource_groups=self.filter_by_resource_groups,
            id=self.id,
            recommendations=self.recommendations)

def get_recommendations(filter_by_categories=None,filter_by_resource_groups=None,opts=None):
    """
    Use this data source to access information about an existing Advisor Recommendations.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.advisor.get_recommendations(filter_by_categories=[
            "security",
            "cost",
        ],
        filter_by_resource_groups=["example-resgroups"])
    pulumi.export("recommendations", example.recommendations)
    ```


    :param list filter_by_categories: Specifies a list of categories in which the Advisor Recommendations will be listed. Possible values are `HighAvailability`, `Security`, `Performance`, `Cost` and `OperationalExcellence`.
    :param list filter_by_resource_groups: Specifies a list of resource groups about which the Advisor Recommendations will be listed.
    """
    __args__ = dict()


    __args__['filterByCategories'] = filter_by_categories
    __args__['filterByResourceGroups'] = filter_by_resource_groups
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:advisor/getRecommendations:getRecommendations', __args__, opts=opts).value

    return AwaitableGetRecommendationsResult(
        filter_by_categories=__ret__.get('filterByCategories'),
        filter_by_resource_groups=__ret__.get('filterByResourceGroups'),
        id=__ret__.get('id'),
        recommendations=__ret__.get('recommendations'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class DpsSharedAccessPolicy(pulumi.CustomResource):
    enrollment_read: pulumi.Output[bool]
    """
    Adds `EnrollmentRead` permission to this Shared Access Account. It allows read access to enrollment data.
    """
    enrollment_write: pulumi.Output[bool]
    """
    Adds `EnrollmentWrite` permission to this Shared Access Account. It allows write access to enrollment data.
    """
    iothub_dps_name: pulumi.Output[str]
    """
    The name of the IoT Hub Device Provisioning service to which this Shared Access Policy belongs. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    Specifies the name of the IotHub Shared Access Policy resource. Changing this forces a new resource to be created.
    """
    primary_connection_string: pulumi.Output[str]
    """
    The primary connection string of the Shared Access Policy.
    """
    primary_key: pulumi.Output[str]
    """
    The primary key used to create the authentication token.
    """
    registration_read: pulumi.Output[bool]
    """
    Adds `RegistrationStatusRead` permission to this Shared Access Account. It allows read access to device registrations.
    """
    registration_write: pulumi.Output[bool]
    """
    Adds `RegistrationStatusWrite` permission to this Shared Access Account. It allows write access to device registrations.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group under which the IotHub Shared Access Policy resource has to be created. Changing this forces a new resource to be created.
    """
    secondary_connection_string: pulumi.Output[str]
    """
    The secondary connection string of the Shared Access Policy.
    """
    secondary_key: pulumi.Output[str]
    """
    The secondary key used to create the authentication token.
    """
    service_config: pulumi.Output[bool]
    """
    Adds `ServiceConfig` permission to this Shared Access Account. It allows configuration of the Device Provisioning Service.
    """
    def __init__(__self__, resource_name, opts=None, enrollment_read=None, enrollment_write=None, iothub_dps_name=None, name=None, registration_read=None, registration_write=None, resource_group_name=None, service_config=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an IotHub Device Provisioning Service Shared Access Policy

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_iot_hub_dps = azure.iot.IotHubDps("exampleIotHubDps",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            sku={
                "name": "S1",
                "capacity": "1",
            })
        example_dps_shared_access_policy = azure.iot.DpsSharedAccessPolicy("exampleDpsSharedAccessPolicy",
            resource_group_name=example_resource_group.name,
            iothub_dps_name=example_iot_hub_dps.name,
            enrollment_write=True,
            enrollment_read=True)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enrollment_read: Adds `EnrollmentRead` permission to this Shared Access Account. It allows read access to enrollment data.
        :param pulumi.Input[bool] enrollment_write: Adds `EnrollmentWrite` permission to this Shared Access Account. It allows write access to enrollment data.
        :param pulumi.Input[str] iothub_dps_name: The name of the IoT Hub Device Provisioning service to which this Shared Access Policy belongs. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the IotHub Shared Access Policy resource. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] registration_read: Adds `RegistrationStatusRead` permission to this Shared Access Account. It allows read access to device registrations.
        :param pulumi.Input[bool] registration_write: Adds `RegistrationStatusWrite` permission to this Shared Access Account. It allows write access to device registrations.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the IotHub Shared Access Policy resource has to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] service_config: Adds `ServiceConfig` permission to this Shared Access Account. It allows configuration of the Device Provisioning Service.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['enrollment_read'] = enrollment_read
            __props__['enrollment_write'] = enrollment_write
            if iothub_dps_name is None:
                raise TypeError("Missing required property 'iothub_dps_name'")
            __props__['iothub_dps_name'] = iothub_dps_name
            __props__['name'] = name
            __props__['registration_read'] = registration_read
            __props__['registration_write'] = registration_write
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['service_config'] = service_config
            __props__['primary_connection_string'] = None
            __props__['primary_key'] = None
            __props__['secondary_connection_string'] = None
            __props__['secondary_key'] = None
        super(DpsSharedAccessPolicy, __self__).__init__(
            'azure:iot/dpsSharedAccessPolicy:DpsSharedAccessPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, enrollment_read=None, enrollment_write=None, iothub_dps_name=None, name=None, primary_connection_string=None, primary_key=None, registration_read=None, registration_write=None, resource_group_name=None, secondary_connection_string=None, secondary_key=None, service_config=None):
        """
        Get an existing DpsSharedAccessPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enrollment_read: Adds `EnrollmentRead` permission to this Shared Access Account. It allows read access to enrollment data.
        :param pulumi.Input[bool] enrollment_write: Adds `EnrollmentWrite` permission to this Shared Access Account. It allows write access to enrollment data.
        :param pulumi.Input[str] iothub_dps_name: The name of the IoT Hub Device Provisioning service to which this Shared Access Policy belongs. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the IotHub Shared Access Policy resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] primary_connection_string: The primary connection string of the Shared Access Policy.
        :param pulumi.Input[str] primary_key: The primary key used to create the authentication token.
        :param pulumi.Input[bool] registration_read: Adds `RegistrationStatusRead` permission to this Shared Access Account. It allows read access to device registrations.
        :param pulumi.Input[bool] registration_write: Adds `RegistrationStatusWrite` permission to this Shared Access Account. It allows write access to device registrations.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the IotHub Shared Access Policy resource has to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] secondary_connection_string: The secondary connection string of the Shared Access Policy.
        :param pulumi.Input[str] secondary_key: The secondary key used to create the authentication token.
        :param pulumi.Input[bool] service_config: Adds `ServiceConfig` permission to this Shared Access Account. It allows configuration of the Device Provisioning Service.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["enrollment_read"] = enrollment_read
        __props__["enrollment_write"] = enrollment_write
        __props__["iothub_dps_name"] = iothub_dps_name
        __props__["name"] = name
        __props__["primary_connection_string"] = primary_connection_string
        __props__["primary_key"] = primary_key
        __props__["registration_read"] = registration_read
        __props__["registration_write"] = registration_write
        __props__["resource_group_name"] = resource_group_name
        __props__["secondary_connection_string"] = secondary_connection_string
        __props__["secondary_key"] = secondary_key
        __props__["service_config"] = service_config
        return DpsSharedAccessPolicy(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class FunctionJavaScriptUDF(pulumi.CustomResource):
    inputs: pulumi.Output[list]
    """
    One or more `input` blocks as defined below.

      * `type` (`str`) - The Data Type for the Input Argument of this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
    """
    name: pulumi.Output[str]
    """
    The name of the JavaScript UDF Function. Changing this forces a new resource to be created.
    """
    output: pulumi.Output[dict]
    """
    An `output` blocks as defined below.

      * `type` (`str`) - The Data Type output from this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the Resource Group where the Stream Analytics Job exists. Changing this forces a new resource to be created.
    """
    script: pulumi.Output[str]
    """
    The JavaScript of this UDF Function.
    """
    stream_analytics_job_name: pulumi.Output[str]
    """
    The name of the Stream Analytics Job where this Function should be created. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, inputs=None, name=None, output=None, resource_group_name=None, script=None, stream_analytics_job_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a JavaScript UDF Function within Stream Analytics Streaming Job.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.get_resource_group(name="example-resources")
        example_job = azure.streamanalytics.get_job(name="example-job",
            resource_group_name=azurerm_resource_group["example"]["name"])
        example_function_java_script_udf = azure.streamanalytics.FunctionJavaScriptUDF("exampleFunctionJavaScriptUDF",
            stream_analytics_job_name=example_job.name,
            resource_group_name=example_job.resource_group_name,
            script=\"\"\"function getRandomNumber(in) {
          return in;
        }
        \"\"\",
            inputs=[{
                "type": "bigint",
            }],
            output={
                "type": "bigint",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] inputs: One or more `input` blocks as defined below.
        :param pulumi.Input[str] name: The name of the JavaScript UDF Function. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] output: An `output` blocks as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Stream Analytics Job exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] script: The JavaScript of this UDF Function.
        :param pulumi.Input[str] stream_analytics_job_name: The name of the Stream Analytics Job where this Function should be created. Changing this forces a new resource to be created.

        The **inputs** object supports the following:

          * `type` (`pulumi.Input[str]`) - The Data Type for the Input Argument of this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.

        The **output** object supports the following:

          * `type` (`pulumi.Input[str]`) - The Data Type output from this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if inputs is None:
                raise TypeError("Missing required property 'inputs'")
            __props__['inputs'] = inputs
            __props__['name'] = name
            if output is None:
                raise TypeError("Missing required property 'output'")
            __props__['output'] = output
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if script is None:
                raise TypeError("Missing required property 'script'")
            __props__['script'] = script
            if stream_analytics_job_name is None:
                raise TypeError("Missing required property 'stream_analytics_job_name'")
            __props__['stream_analytics_job_name'] = stream_analytics_job_name
        super(FunctionJavaScriptUDF, __self__).__init__(
            'azure:streamanalytics/functionJavaScriptUDF:FunctionJavaScriptUDF',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, inputs=None, name=None, output=None, resource_group_name=None, script=None, stream_analytics_job_name=None):
        """
        Get an existing FunctionJavaScriptUDF resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] inputs: One or more `input` blocks as defined below.
        :param pulumi.Input[str] name: The name of the JavaScript UDF Function. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] output: An `output` blocks as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Stream Analytics Job exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] script: The JavaScript of this UDF Function.
        :param pulumi.Input[str] stream_analytics_job_name: The name of the Stream Analytics Job where this Function should be created. Changing this forces a new resource to be created.

        The **inputs** object supports the following:

          * `type` (`pulumi.Input[str]`) - The Data Type for the Input Argument of this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.

        The **output** object supports the following:

          * `type` (`pulumi.Input[str]`) - The Data Type output from this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["inputs"] = inputs
        __props__["name"] = name
        __props__["output"] = output
        __props__["resource_group_name"] = resource_group_name
        __props__["script"] = script
        __props__["stream_analytics_job_name"] = stream_analytics_job_name
        return FunctionJavaScriptUDF(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class Definition(pulumi.CustomResource):
    authorizations: pulumi.Output[list]
    """
    One or more `authorization` block defined below.

      * `role_definition_id` (`str`) - Specifies a role definition identifier for the provider. This role will define all the permissions that the provider must have on the managed application's container resource group. This role definition cannot have permission to delete the resource group.
      * `service_principal_id` (`str`) - Specifies a service principal identifier for the provider. This is the identity that the provider will use to call ARM to manage the managed application resources.
    """
    create_ui_definition: pulumi.Output[str]
    """
    Specifies the `createUiDefinition` json for the backing template with `Microsoft.Solutions/applications` resource.
    """
    description: pulumi.Output[str]
    """
    Specifies the managed application definition description.
    """
    display_name: pulumi.Output[str]
    """
    Specifies the managed application definition display name.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    lock_level: pulumi.Output[str]
    """
    Specifies the managed application lock level. Valid values include `CanNotDelete`, `None`, `ReadOnly`. Changing this forces a new resource to be created.
    """
    main_template: pulumi.Output[str]
    """
    Specifies the inline main template json which has resources to be provisioned.
    """
    name: pulumi.Output[str]
    """
    Specifies the name of the Managed Application Definition. Changing this forces a new resource to be created.
    """
    package_enabled: pulumi.Output[bool]
    """
    Is the package enabled? Defaults to `true`.
    """
    package_file_uri: pulumi.Output[str]
    """
    Specifies the managed application definition package file Uri.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the Resource Group where the Managed Application Definition should exist. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    def __init__(__self__, resource_name, opts=None, authorizations=None, create_ui_definition=None, description=None, display_name=None, location=None, lock_level=None, main_template=None, name=None, package_enabled=None, package_file_uri=None, resource_group_name=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Managed Application Definition.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_definition = azure.managedapplication.Definition("exampleDefinition",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            lock_level="ReadOnly",
            package_file_uri="https://github.com/Azure/azure-managedapp-samples/raw/master/Managed Application Sample Packages/201-managed-storage-account/managedstorage.zip",
            display_name="TestManagedApplicationDefinition",
            description="Test Managed Application Definition",
            authorizations=[{
                "service_principal_id": current.object_id,
                "role_definition_id": "a094b430-dad3-424d-ae58-13f72fd72591",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] authorizations: One or more `authorization` block defined below.
        :param pulumi.Input[str] create_ui_definition: Specifies the `createUiDefinition` json for the backing template with `Microsoft.Solutions/applications` resource.
        :param pulumi.Input[str] description: Specifies the managed application definition description.
        :param pulumi.Input[str] display_name: Specifies the managed application definition display name.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] lock_level: Specifies the managed application lock level. Valid values include `CanNotDelete`, `None`, `ReadOnly`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] main_template: Specifies the inline main template json which has resources to be provisioned.
        :param pulumi.Input[str] name: Specifies the name of the Managed Application Definition. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] package_enabled: Is the package enabled? Defaults to `true`.
        :param pulumi.Input[str] package_file_uri: Specifies the managed application definition package file Uri.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Managed Application Definition should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **authorizations** object supports the following:

          * `role_definition_id` (`pulumi.Input[str]`) - Specifies a role definition identifier for the provider. This role will define all the permissions that the provider must have on the managed application's container resource group. This role definition cannot have permission to delete the resource group.
          * `service_principal_id` (`pulumi.Input[str]`) - Specifies a service principal identifier for the provider. This is the identity that the provider will use to call ARM to manage the managed application resources.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['authorizations'] = authorizations
            __props__['create_ui_definition'] = create_ui_definition
            __props__['description'] = description
            if display_name is None:
                raise TypeError("Missing required property 'display_name'")
            __props__['display_name'] = display_name
            __props__['location'] = location
            if lock_level is None:
                raise TypeError("Missing required property 'lock_level'")
            __props__['lock_level'] = lock_level
            __props__['main_template'] = main_template
            __props__['name'] = name
            __props__['package_enabled'] = package_enabled
            __props__['package_file_uri'] = package_file_uri
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
        super(Definition, __self__).__init__(
            'azure:managedapplication/definition:Definition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, authorizations=None, create_ui_definition=None, description=None, display_name=None, location=None, lock_level=None, main_template=None, name=None, package_enabled=None, package_file_uri=None, resource_group_name=None, tags=None):
        """
        Get an existing Definition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] authorizations: One or more `authorization` block defined below.
        :param pulumi.Input[str] create_ui_definition: Specifies the `createUiDefinition` json for the backing template with `Microsoft.Solutions/applications` resource.
        :param pulumi.Input[str] description: Specifies the managed application definition description.
        :param pulumi.Input[str] display_name: Specifies the managed application definition display name.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] lock_level: Specifies the managed application lock level. Valid values include `CanNotDelete`, `None`, `ReadOnly`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] main_template: Specifies the inline main template json which has resources to be provisioned.
        :param pulumi.Input[str] name: Specifies the name of the Managed Application Definition. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] package_enabled: Is the package enabled? Defaults to `true`.
        :param pulumi.Input[str] package_file_uri: Specifies the managed application definition package file Uri.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Managed Application Definition should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **authorizations** object supports the following:

          * `role_definition_id` (`pulumi.Input[str]`) - Specifies a role definition identifier for the provider. This role will define all the permissions that the provider must have on the managed application's container resource group. This role definition cannot have permission to delete the resource group.
          * `service_principal_id` (`pulumi.Input[str]`) - Specifies a service principal identifier for the provider. This is the identity that the provider will use to call ARM to manage the managed application resources.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["authorizations"] = authorizations
        __props__["create_ui_definition"] = create_ui_definition
        __props__["description"] = description
        __props__["display_name"] = display_name
        __props__["location"] = location
        __props__["lock_level"] = lock_level
        __props__["main_template"] = main_template
        __props__["name"] = name
        __props__["package_enabled"] = package_enabled
        __props__["package_file_uri"] = package_file_uri
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        return Definition(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetPolicyResult:
    """
    A collection of values returned by getPolicy.
    """
    def __init__(__self__, id=None, rules=None, storage_account_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        __self__.rules = rules
        """
        A `rule` block as documented below.
        """
        if storage_account_id and not isinstance(storage_account_id, str):
            raise TypeError("Expected argument 'storage_account_id' to be a str")
        __self__.storage_account_id = storage_account_id
class AwaitableGetPolicyResult(GetPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyResult(
            id=self.id,
            rules=self.rules,
            storage_account_id=self.storage_account_id)

def get_policy(storage_account_id=None,opts=None):
    """
    Use this data source to access information about an existing Storage Management Policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_account = azure.storage.get_account(name="storageaccountname",
        resource_group_name="resourcegroupname")
    example_policy = azure.storage.get_policy(storage_account_id=azurerm_storage_account["example"]["id"])
    ```


    :param str storage_account_id: Specifies the id of the storage account to retrieve the management policy for.
    """
    __args__ = dict()


    __args__['storageAccountId'] = storage_account_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:storage/getPolicy:getPolicy', __args__, opts=opts).value

    return AwaitableGetPolicyResult(
        id=__ret__.get('id'),
        rules=__ret__.get('rules'),
        storage_account_id=__ret__.get('storageAccountId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetDpsResult:
    """
    A collection of values returned by getDps.
    """
    def __init__(__self__, allocation_policy=None, device_provisioning_host_name=None, id=None, id_scope=None, location=None, name=None, resource_group_name=None, service_operations_host_name=None, tags=None):
        if allocation_policy and not isinstance(allocation_policy, str):
            raise TypeError("Expected argument 'allocation_policy' to be a str")
        __self__.allocation_policy = allocation_policy
        """
        The allocation policy of the IoT Device Provisioning Service.
        """
        if device_provisioning_host_name and not isinstance(device_provisioning_host_name, str):
            raise TypeError("Expected argument 'device_provisioning_host_name' to be a str")
        __self__.device_provisioning_host_name = device_provisioning_host_name
        """
        The device endpoint of the IoT Device Provisioning Service.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if id_scope and not isinstance(id_scope, str):
            raise TypeError("Expected argument 'id_scope' to be a str")
        __self__.id_scope = id_scope
        """
        The unique identifier of the IoT Device Provisioning Service.
        """
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        __self__.location = location
        """
        Specifies the supported Azure location where the IoT Device Provisioning Service exists.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        __self__.resource_group_name = resource_group_name
        if service_operations_host_name and not isinstance(service_operations_host_name, str):
            raise TypeError("Expected argument 'service_operations_host_name' to be a str")
        __self__.service_operations_host_name = service_operations_host_name
        """
        The service endpoint of the IoT Device Provisioning Service.
        """
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
class AwaitableGetDpsResult(GetDpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDpsResult(
            allocation_policy=self.allocation_policy,
            device_provisioning_host_name=self.device_provisioning_host_name,
            id=self.id,
            id_scope=self.id_scope,
            location=self.location,
            name=self.name,
            resource_group_name=self.resource_group_name,
            service_operations_host_name=self.service_operations_host_name,
            tags=self.tags)

def get_dps(name=None,resource_group_name=None,tags=None,opts=None):
    """
    Use this data source to access information about an existing IotHub Device Provisioning Service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.iot.get_dps(name="iot_hub_dps_test",
        resource_group_name="iothub_dps_rg")
    ```


    :param str name: Specifies the name of the Iot Device Provisioning Service resource.
    :param str resource_group_name: The name of the resource group under which the Iot Device Provisioning Service is located in.
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:iot/getDps:getDps', __args__, opts=opts).value

    return AwaitableGetDpsResult(
        allocation_policy=__ret__.get('allocationPolicy'),
        device_provisioning_host_name=__ret__.get('deviceProvisioningHostName'),
        id=__ret__.get('id'),
        id_scope=__ret__.get('idScope'),
        location=__ret__.get('location'),
        name=__ret__.get('name'),
        resource_group_name=__ret__.get('resourceGroupName'),
        service_operations_host_name=__ret__.get('serviceOperationsHostName'),
        tags=__ret__.get('tags'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import importlib
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
_submodules = [
    'advisor',
    'analysisservices',
    'apimanagement',
    'appconfiguration',
    'appinsights',
    'appplatform',
    'appservice',
    'authorization',
    'automation',
    'backup',
    'batch',
    'blueprint',
    'bot',
    'cdn',
    'cognitive',
    'compute',
    'config',
    'containerservice',
    'core',
    'cosmosdb',
    'costmanagement',
    'dashboard',
    'databasemigration',
    'databricks',
    'datafactory',
    'datalake',
    'datashare',
    'devspace',
    'devtest',
    'dns',
    'eventgrid',
    'eventhub',
    'frontdoor',
    'hdinsight',
    'healthcare',
    'hpc',
    'iot',
    'iotcentral',
    'keyvault',
    'kusto',
    'lb',
    'loganalytics',
    'logicapps',
    'machinelearning',
    'maintenance',
    'managedapplication',
    'management',
    'managementgroups',
    'managementresource',
    'maps',
    'mariadb',
    'marketplace',
    'mediaservices',
    'mixedreality',
    'monitoring',
    'msi',
    'mssql',
    'mysql',
    'netapp',
    'network',
    'notificationhub',
    'operationalinsights',
    'policy',
    'postgresql',
    'powerbi',
    'privatedns',
    'privatelink',
    'proximity',
    'recoveryservices',
    'redis',
    'relay',
    'role',
    'search',
    'securitycenter',
    'sentinel',
    'servicebus',
    'servicefabric',
    'signalr',
    'siterecovery',
    'sql',
    'storage',
    'streamanalytics',
    'trafficmanager',
    'waf',
]
for pkg in _submodules:
    if pkg != 'config':
        importlib.import_module(f'{__name__}.{pkg}')



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class Frontdoor(pulumi.CustomResource):
    backend_pool_health_probes: pulumi.Output[list]
    """
    A `backend_pool_health_probe` block as defined below.

      * `enabled` (`bool`) - Is this health probe enabled? Dafaults to `true`.
      * `id` (`str`) - The ID of the FrontDoor.
      * `interval_in_seconds` (`float`) - The number of seconds between each Health Probe. Defaults to `120`.
      * `name` (`str`) - Specifies the name of the Health Probe.
      * `path` (`str`) - The path to use for the Health Probe. Default is `/`.
      * `probeMethod` (`str`) - Specifies HTTP method the health probe uses when querying the backend pool instances. Possible values include: `Get` and `Head`. Defaults to `Get`.
      * `protocol` (`str`) - Protocol scheme to use for the Health Probe. Defaults to `Http`.
    """
    backend_pool_load_balancings: pulumi.Output[list]
    """
    A `backend_pool_load_balancing` block as defined below.

      * `additionalLatencyMilliseconds` (`float`) - The additional latency in milliseconds for probes to fall into the lowest latency bucket. Defaults to `0`.
      * `id` (`str`) - The ID of the FrontDoor.
      * `name` (`str`) - Specifies the name of the Load Balancer.
      * `sampleSize` (`float`) - The number of samples to consider for load balancing decisions. Defaults to `4`.
      * `successfulSamplesRequired` (`float`) - The number of samples within the sample period that must succeed. Defaults to `2`.
    """
    backend_pools: pulumi.Output[list]
    """
    A `backend_pool` block as defined below.

      * `backends` (`list`) - A `backend` block as defined below.
        * `address` (`str`) - Location of the backend (IP address or FQDN)
        * `enabled` (`bool`) - Specifies if the backend is enabled or not. Valid options are `true` or `false`. Defaults to `true`.
        * `hostHeader` (`str`) - The value to use as the host header sent to the backend.
        * `httpPort` (`float`) - The HTTP TCP port number. Possible values are between `1` - `65535`.
        * `httpsPort` (`float`) - The HTTPS TCP port number. Possible values are between `1` - `65535`.
        * `priority` (`float`) - Priority to use for load balancing. Higher priorities will not be used for load balancing if any lower priority backend is healthy. Defaults to `1`.
        * `weight` (`float`) - Weight of this endpoint for load balancing purposes. Defaults to `50`.

      * `healthProbeName` (`str`) - Specifies the name of the `backend_pool_health_probe` block whithin this resource to use for this `Backend Pool`.
      * `id` (`str`) - The ID of the FrontDoor.
      * `loadBalancingName` (`str`) - Specifies the name of the `backend_pool_load_balancing` block within this resource to use for this `Backend Pool`.
      * `name` (`str`) - Specifies the name of the Backend Pool.
    """
    backend_pools_send_receive_timeout_seconds: pulumi.Output[float]
    """
    Specifies the send and receive timeout on forwarding request to the backend. When the timeout is reached, the request fails and returns. Possible values are between `0` - `240`. Defaults to `60`.
    """
    cname: pulumi.Output[str]
    """
    The host that each frontendEndpoint must CNAME to.
    """
    enforce_backend_pools_certificate_name_check: pulumi.Output[bool]
    """
    Enforce certificate name check on `HTTPS` requests to all backend pools, this setting will have no effect on `HTTP` requests. Permitted values are `true` or `false`.
    """
    friendly_name: pulumi.Output[str]
    """
    A friendly name for the Front Door service.
    """
    frontend_endpoints: pulumi.Output[list]
    """
    A `frontend_endpoint` block as defined below.

      * `customHttpsConfiguration` (`dict`) - A `custom_https_configuration` block as defined below.
        * `azureKeyVaultCertificateSecretName` (`str`) - The name of the Key Vault secret representing the full certificate PFX.
        * `azureKeyVaultCertificateSecretVersion` (`str`) - The version of the Key Vault secret representing the full certificate PFX.
        * `azureKeyVaultCertificateVaultId` (`str`) - The ID of the Key Vault containing the SSL certificate.
        * `certificateSource` (`str`) - Certificate source to encrypted `HTTPS` traffic with. Allowed values are `FrontDoor` or `AzureKeyVault`. Defaults to `FrontDoor`.
        * `minimum_tls_version` (`str`) - Minimum client TLS version supported.
        * `provisioningState` (`str`) - Provisioning state of the Front Door.
        * `provisioningSubstate` (`str`) - Provisioning substate of the Front Door

      * `customHttpsProvisioningEnabled` (`bool`) - Should the HTTPS protocol be enabled for a custom domain associated with the Front Door?
      * `host_name` (`str`) - Specifies the host name of the `frontend_endpoint`. Must be a domain name.
      * `id` (`str`) - The ID of the FrontDoor.
      * `name` (`str`) - Specifies the name of the `frontend_endpoint`.
      * `sessionAffinityEnabled` (`bool`) - Whether to allow session affinity on this host. Valid options are `true` or `false` Defaults to `false`.
      * `sessionAffinityTtlSeconds` (`float`) - The TTL to use in seconds for session affinity, if applicable. Defaults to `0`.
      * `webApplicationFirewallPolicyLinkId` (`str`) - Defines the Web Application Firewall policy `ID` for each host.
    """
    header_frontdoor_id: pulumi.Output[str]
    """
    The unique ID of the Front Door which is embedded into the incoming headers `X-Azure-FDID` attribute and maybe used to filter traffic sent by the Front Door to your backend.
    """
    load_balancer_enabled: pulumi.Output[bool]
    """
    Should the Front Door Load Balancer be Enabled? Defaults to `true`.
    """
    location: pulumi.Output[str]
    name: pulumi.Output[str]
    """
    Specifies the name of the Front Door service. Changing this forces a new resource to be created.
    """
    resource_group_name: pulumi.Output[str]
    """
    Specifies the name of the Resource Group in which the Front Door service should exist. Changing this forces a new resource to be created.
    """
    routing_rules: pulumi.Output[list]
    """
    A `routing_rule` block as defined below.

      * `acceptedProtocols` (`list`) - Protocol schemes to match for the Backend Routing Rule. Defaults to `Http`.
      * `enabled` (`bool`) - `Enable` or `Disable` use of this Backend Routing Rule. Permitted values are `true` or `false`. Defaults to `true`.
      * `forwardingConfiguration` (`dict`) - A `forwarding_configuration` block as defined below.
        * `backendPoolName` (`str`) - Specifies the name of the Backend Pool to forward the incoming traffic to.
        * `cacheEnabled` (`bool`) - Specifies whether to Enable caching or not. Valid options are `true` or `false`. Defaults to `false`.
        * `cacheQueryParameterStripDirective` (`str`) - Defines cache behavior in releation to query string parameters. Valid options are `StripAll` or `StripNone`. Defaults to `StripAll`.
        * `cacheUseDynamicCompression` (`bool`) - Whether to use dynamic compression when caching. Valid options are `true` or `false`. Defaults to `false`.
        * `customForwardingPath` (`str`) - Path to use when constructing the request to forward to the backend. This functions as a URL Rewrite. Default behavior preserves the URL path.
        * `forwardingProtocol` (`str`) - Protocol to use when redirecting. Valid options are `HttpOnly`, `HttpsOnly`, or `MatchRequest`. Defaults to `HttpsOnly`.

      * `frontend_endpoints` (`list`) - The names of the `frontend_endpoint` blocks whithin this resource to associate with this `routing_rule`.
      * `id` (`str`) - The ID of the FrontDoor.
      * `name` (`str`) - Specifies the name of the Routing Rule.
      * `patternsToMatches` (`list`) - The route patterns for the Backend Routing Rule. Defaults to `/*`.
      * `redirectConfiguration` (`dict`) - A `redirect_configuration` block as defined below.
        * `customFragment` (`str`) - The destination fragment in the portion of URL after '#'. Set this to add a fragment to the redirect URL.
        * `customHost` (`str`) - Set this to change the URL for the redirection.
        * `customPath` (`str`) - The path to retain as per the incoming request, or update in the URL for the redirection.
        * `customQueryString` (`str`) - Replace any existing query string from the incoming request URL.
        * `redirectProtocol` (`str`) - Protocol to use when redirecting. Valid options are `HttpOnly`, `HttpsOnly`, or `MatchRequest`. Defaults to `MatchRequest`
        * `redirectType` (`str`) - Status code for the redirect. Valida options are `Moved`, `Found`, `TemporaryRedirect`, `PermanentRedirect`.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    def __init__(__self__, resource_name, opts=None, backend_pool_health_probes=None, backend_pool_load_balancings=None, backend_pools=None, backend_pools_send_receive_timeout_seconds=None, enforce_backend_pools_certificate_name_check=None, friendly_name=None, frontend_endpoints=None, load_balancer_enabled=None, location=None, name=None, resource_group_name=None, routing_rules=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Azure Front Door instance.

        Azure Front Door Service is Microsoft's highly available and scalable web application acceleration platform and global HTTP(s) load balancer. It provides built-in DDoS protection and application layer security and caching. Front Door enables you to build applications that maximize and automate high-availability and performance for your end-users. Use Front Door with Azure services including Web/Mobile Apps, Cloud Services and Virtual Machines – or combine it with on-premises services for hybrid deployments and smooth cloud migration.

        Below are some of the key scenarios that Azure Front Door Service addresses:
        * Use Front Door to improve application scale and availability with instant multi-region failover
        * Use Front Door to improve application performance with SSL offload and routing requests to the fastest available application backend.
        * Use Front Door for application layer security and DDoS protection for your application.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="EastUS2")
        example_frontdoor = azure.frontdoor.Frontdoor("exampleFrontdoor",
            resource_group_name=example_resource_group.name,
            enforce_backend_pools_certificate_name_check=False,
            routing_rules=[{
                "name": "exampleRoutingRule1",
                "acceptedProtocols": [
                    "Http",
                    "Https",
                ],
                "patternsToMatches": ["/*"],
                "frontend_endpoints": ["exampleFrontendEndpoint1"],
                "forwardingConfiguration": {
                    "forwardingProtocol": "MatchRequest",
                    "backendPoolName": "exampleBackendBing",
                },
            }],
            backend_pool_load_balancings=[{
                "name": "exampleLoadBalancingSettings1",
            }],
            backend_pool_health_probes=[{
                "name": "exampleHealthProbeSetting1",
            }],
            backend_pools=[{
                "name": "exampleBackendBing",
                "backends": [{
                    "hostHeader": "www.bing.com",
                    "address": "www.bing.com",
                    "httpPort": 80,
                    "httpsPort": 443,
                }],
                "loadBalancingName": "exampleLoadBalancingSettings1",
                "healthProbeName": "exampleHealthProbeSetting1",
            }],
            frontend_endpoints=[{
                "name": "exampleFrontendEndpoint1",
                "host_name": "example-FrontDoor.azurefd.net",
                "customHttpsProvisioningEnabled": False,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] backend_pool_health_probes: A `backend_pool_health_probe` block as defined below.
        :param pulumi.Input[list] backend_pool_load_balancings: A `backend_pool_load_balancing` block as defined below.
        :param pulumi.Input[list] backend_pools: A `backend_pool` block as defined below.
        :param pulumi.Input[float] backend_pools_send_receive_timeout_seconds: Specifies the send and receive timeout on forwarding request to the backend. When the timeout is reached, the request fails and returns. Possible values are between `0` - `240`. Defaults to `60`.
        :param pulumi.Input[bool] enforce_backend_pools_certificate_name_check: Enforce certificate name check on `HTTPS` requests to all backend pools, this setting will have no effect on `HTTP` requests. Permitted values are `true` or `false`.
        :param pulumi.Input[str] friendly_name: A friendly name for the Front Door service.
        :param pulumi.Input[list] frontend_endpoints: A `frontend_endpoint` block as defined below.
        :param pulumi.Input[bool] load_balancer_enabled: Should the Front Door Load Balancer be Enabled? Defaults to `true`.
        :param pulumi.Input[str] name: Specifies the name of the Front Door service. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Specifies the name of the Resource Group in which the Front Door service should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[list] routing_rules: A `routing_rule` block as defined below.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **backend_pool_health_probes** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Is this health probe enabled? Dafaults to `true`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `interval_in_seconds` (`pulumi.Input[float]`) - The number of seconds between each Health Probe. Defaults to `120`.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Health Probe.
          * `path` (`pulumi.Input[str]`) - The path to use for the Health Probe. Default is `/`.
          * `probeMethod` (`pulumi.Input[str]`) - Specifies HTTP method the health probe uses when querying the backend pool instances. Possible values include: `Get` and `Head`. Defaults to `Get`.
          * `protocol` (`pulumi.Input[str]`) - Protocol scheme to use for the Health Probe. Defaults to `Http`.

        The **backend_pool_load_balancings** object supports the following:

          * `additionalLatencyMilliseconds` (`pulumi.Input[float]`) - The additional latency in milliseconds for probes to fall into the lowest latency bucket. Defaults to `0`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Load Balancer.
          * `sampleSize` (`pulumi.Input[float]`) - The number of samples to consider for load balancing decisions. Defaults to `4`.
          * `successfulSamplesRequired` (`pulumi.Input[float]`) - The number of samples within the sample period that must succeed. Defaults to `2`.

        The **backend_pools** object supports the following:

          * `backends` (`pulumi.Input[list]`) - A `backend` block as defined below.
            * `address` (`pulumi.Input[str]`) - Location of the backend (IP address or FQDN)
            * `enabled` (`pulumi.Input[bool]`) - Specifies if the backend is enabled or not. Valid options are `true` or `false`. Defaults to `true`.
            * `hostHeader` (`pulumi.Input[str]`) - The value to use as the host header sent to the backend.
            * `httpPort` (`pulumi.Input[float]`) - The HTTP TCP port number. Possible values are between `1` - `65535`.
            * `httpsPort` (`pulumi.Input[float]`) - The HTTPS TCP port number. Possible values are between `1` - `65535`.
            * `priority` (`pulumi.Input[float]`) - Priority to use for load balancing. Higher priorities will not be used for load balancing if any lower priority backend is healthy. Defaults to `1`.
            * `weight` (`pulumi.Input[float]`) - Weight of this endpoint for load balancing purposes. Defaults to `50`.

          * `healthProbeName` (`pulumi.Input[str]`) - Specifies the name of the `backend_pool_health_probe` block whithin this resource to use for this `Backend Pool`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `loadBalancingName` (`pulumi.Input[str]`) - Specifies the name of the `backend_pool_load_balancing` block within this resource to use for this `Backend Pool`.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Backend Pool.

        The **frontend_endpoints** object supports the following:

          * `customHttpsConfiguration` (`pulumi.Input[dict]`) - A `custom_https_configuration` block as defined below.
            * `azureKeyVaultCertificateSecretName` (`pulumi.Input[str]`) - The name of the Key Vault secret representing the full certificate PFX.
            * `azureKeyVaultCertificateSecretVersion` (`pulumi.Input[str]`) - The version of the Key Vault secret representing the full certificate PFX.
            * `azureKeyVaultCertificateVaultId` (`pulumi.Input[str]`) - The ID of the Key Vault containing the SSL certificate.
            * `certificateSource` (`pulumi.Input[str]`) - Certificate source to encrypted `HTTPS` traffic with. Allowed values are `FrontDoor` or `AzureKeyVault`. Defaults to `FrontDoor`.
            * `minimum_tls_version` (`pulumi.Input[str]`) - Minimum client TLS version supported.
            * `provisioningState` (`pulumi.Input[str]`) - Provisioning state of the Front Door.
            * `provisioningSubstate` (`pulumi.Input[str]`) - Provisioning substate of the Front Door

          * `customHttpsProvisioningEnabled` (`pulumi.Input[bool]`) - Should the HTTPS protocol be enabled for a custom domain associated with the Front Door?
          * `host_name` (`pulumi.Input[str]`) - Specifies the host name of the `frontend_endpoint`. Must be a domain name.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the `frontend_endpoint`.
          * `sessionAffinityEnabled` (`pulumi.Input[bool]`) - Whether to allow session affinity on this host. Valid options are `true` or `false` Defaults to `false`.
          * `sessionAffinityTtlSeconds` (`pulumi.Input[float]`) - The TTL to use in seconds for session affinity, if applicable. Defaults to `0`.
          * `webApplicationFirewallPolicyLinkId` (`pulumi.Input[str]`) - Defines the Web Application Firewall policy `ID` for each host.

        The **routing_rules** object supports the following:

          * `acceptedProtocols` (`pulumi.Input[list]`) - Protocol schemes to match for the Backend Routing Rule. Defaults to `Http`.
          * `enabled` (`pulumi.Input[bool]`) - `Enable` or `Disable` use of this Backend Routing Rule. Permitted values are `true` or `false`. Defaults to `true`.
          * `forwardingConfiguration` (`pulumi.Input[dict]`) - A `forwarding_configuration` block as defined below.
            * `backendPoolName` (`pulumi.Input[str]`) - Specifies the name of the Backend Pool to forward the incoming traffic to.
            * `cacheEnabled` (`pulumi.Input[bool]`) - Specifies whether to Enable caching or not. Valid options are `true` or `false`. Defaults to `false`.
            * `cacheQueryParameterStripDirective` (`pulumi.Input[str]`) - Defines cache behavior in releation to query string parameters. Valid options are `StripAll` or `StripNone`. Defaults to `StripAll`.
            * `cacheUseDynamicCompression` (`pulumi.Input[bool]`) - Whether to use dynamic compression when caching. Valid options are `true` or `false`. Defaults to `false`.
            * `customForwardingPath` (`pulumi.Input[str]`) - Path to use when constructing the request to forward to the backend. This functions as a URL Rewrite. Default behavior preserves the URL path.
            * `forwardingProtocol` (`pulumi.Input[str]`) - Protocol to use when redirecting. Valid options are `HttpOnly`, `HttpsOnly`, or `MatchRequest`. Defaults to `HttpsOnly`.

          * `frontend_endpoints` (`pulumi.Input[list]`) - The names of the `frontend_endpoint` blocks whithin this resource to associate with this `routing_rule`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Routing Rule.
          * `patternsToMatches` (`pulumi.Input[list]`) - The route patterns for the Backend Routing Rule. Defaults to `/*`.
          * `redirectConfiguration` (`pulumi.Input[dict]`) - A `redirect_configuration` block as defined below.
            * `customFragment` (`pulumi.Input[str]`) - The destination fragment in the portion of URL after '#'. Set this to add a fragment to the redirect URL.
            * `customHost` (`pulumi.Input[str]`) - Set this to change the URL for the redirection.
            * `customPath` (`pulumi.Input[str]`) - The path to retain as per the incoming request, or update in the URL for the redirection.
            * `customQueryString` (`pulumi.Input[str]`) - Replace any existing query string from the incoming request URL.
            * `redirectProtocol` (`pulumi.Input[str]`) - Protocol to use when redirecting. Valid options are `HttpOnly`, `HttpsOnly`, or `MatchRequest`. Defaults to `MatchRequest`
            * `redirectType` (`pulumi.Input[str]`) - Status code for the redirect. Valida options are `Moved`, `Found`, `TemporaryRedirect`, `PermanentRedirect`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if backend_pool_health_probes is None:
                raise TypeError("Missing required property 'backend_pool_health_probes'")
            __props__['backend_pool_health_probes'] = backend_pool_health_probes
            if backend_pool_load_balancings is None:
                raise TypeError("Missing required property 'backend_pool_load_balancings'")
            __props__['backend_pool_load_balancings'] = backend_pool_load_balancings
            if backend_pools is None:
                raise TypeError("Missing required property 'backend_pools'")
            __props__['backend_pools'] = backend_pools
            __props__['backend_pools_send_receive_timeout_seconds'] = backend_pools_send_receive_timeout_seconds
            if enforce_backend_pools_certificate_name_check is None:
                raise TypeError("Missing required property 'enforce_backend_pools_certificate_name_check'")
            __props__['enforce_backend_pools_certificate_name_check'] = enforce_backend_pools_certificate_name_check
            __props__['friendly_name'] = friendly_name
            if frontend_endpoints is None:
                raise TypeError("Missing required property 'frontend_endpoints'")
            __props__['frontend_endpoints'] = frontend_endpoints
            __props__['load_balancer_enabled'] = load_balancer_enabled
            if location is not None:
                warnings.warn("Due to the service's API changing 'location' must now always be set to 'Global' for new resources, however if the Front Door service was created prior 2020/03/10 it may continue to exist in a specific current location", DeprecationWarning)
                pulumi.log.warn("location is deprecated: Due to the service's API changing 'location' must now always be set to 'Global' for new resources, however if the Front Door service was created prior 2020/03/10 it may continue to exist in a specific current location")
            __props__['location'] = location
            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if routing_rules is None:
                raise TypeError("Missing required property 'routing_rules'")
            __props__['routing_rules'] = routing_rules
            __props__['tags'] = tags
            __props__['cname'] = None
            __props__['header_frontdoor_id'] = None
        super(Frontdoor, __self__).__init__(
            'azure:frontdoor/frontdoor:Frontdoor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, backend_pool_health_probes=None, backend_pool_load_balancings=None, backend_pools=None, backend_pools_send_receive_timeout_seconds=None, cname=None, enforce_backend_pools_certificate_name_check=None, friendly_name=None, frontend_endpoints=None, header_frontdoor_id=None, load_balancer_enabled=None, location=None, name=None, resource_group_name=None, routing_rules=None, tags=None):
        """
        Get an existing Frontdoor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] backend_pool_health_probes: A `backend_pool_health_probe` block as defined below.
        :param pulumi.Input[list] backend_pool_load_balancings: A `backend_pool_load_balancing` block as defined below.
        :param pulumi.Input[list] backend_pools: A `backend_pool` block as defined below.
        :param pulumi.Input[float] backend_pools_send_receive_timeout_seconds: Specifies the send and receive timeout on forwarding request to the backend. When the timeout is reached, the request fails and returns. Possible values are between `0` - `240`. Defaults to `60`.
        :param pulumi.Input[str] cname: The host that each frontendEndpoint must CNAME to.
        :param pulumi.Input[bool] enforce_backend_pools_certificate_name_check: Enforce certificate name check on `HTTPS` requests to all backend pools, this setting will have no effect on `HTTP` requests. Permitted values are `true` or `false`.
        :param pulumi.Input[str] friendly_name: A friendly name for the Front Door service.
        :param pulumi.Input[list] frontend_endpoints: A `frontend_endpoint` block as defined below.
        :param pulumi.Input[str] header_frontdoor_id: The unique ID of the Front Door which is embedded into the incoming headers `X-Azure-FDID` attribute and maybe used to filter traffic sent by the Front Door to your backend.
        :param pulumi.Input[bool] load_balancer_enabled: Should the Front Door Load Balancer be Enabled? Defaults to `true`.
        :param pulumi.Input[str] name: Specifies the name of the Front Door service. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Specifies the name of the Resource Group in which the Front Door service should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[list] routing_rules: A `routing_rule` block as defined below.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **backend_pool_health_probes** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Is this health probe enabled? Dafaults to `true`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `interval_in_seconds` (`pulumi.Input[float]`) - The number of seconds between each Health Probe. Defaults to `120`.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Health Probe.
          * `path` (`pulumi.Input[str]`) - The path to use for the Health Probe. Default is `/`.
          * `probeMethod` (`pulumi.Input[str]`) - Specifies HTTP method the health probe uses when querying the backend pool instances. Possible values include: `Get` and `Head`. Defaults to `Get`.
          * `protocol` (`pulumi.Input[str]`) - Protocol scheme to use for the Health Probe. Defaults to `Http`.

        The **backend_pool_load_balancings** object supports the following:

          * `additionalLatencyMilliseconds` (`pulumi.Input[float]`) - The additional latency in milliseconds for probes to fall into the lowest latency bucket. Defaults to `0`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Load Balancer.
          * `sampleSize` (`pulumi.Input[float]`) - The number of samples to consider for load balancing decisions. Defaults to `4`.
          * `successfulSamplesRequired` (`pulumi.Input[float]`) - The number of samples within the sample period that must succeed. Defaults to `2`.

        The **backend_pools** object supports the following:

          * `backends` (`pulumi.Input[list]`) - A `backend` block as defined below.
            * `address` (`pulumi.Input[str]`) - Location of the backend (IP address or FQDN)
            * `enabled` (`pulumi.Input[bool]`) - Specifies if the backend is enabled or not. Valid options are `true` or `false`. Defaults to `true`.
            * `hostHeader` (`pulumi.Input[str]`) - The value to use as the host header sent to the backend.
            * `httpPort` (`pulumi.Input[float]`) - The HTTP TCP port number. Possible values are between `1` - `65535`.
            * `httpsPort` (`pulumi.Input[float]`) - The HTTPS TCP port number. Possible values are between `1` - `65535`.
            * `priority` (`pulumi.Input[float]`) - Priority to use for load balancing. Higher priorities will not be used for load balancing if any lower priority backend is healthy. Defaults to `1`.
            * `weight` (`pulumi.Input[float]`) - Weight of this endpoint for load balancing purposes. Defaults to `50`.

          * `healthProbeName` (`pulumi.Input[str]`) - Specifies the name of the `backend_pool_health_probe` block whithin this resource to use for this `Backend Pool`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `loadBalancingName` (`pulumi.Input[str]`) - Specifies the name of the `backend_pool_load_balancing` block within this resource to use for this `Backend Pool`.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Backend Pool.

        The **frontend_endpoints** object supports the following:

          * `customHttpsConfiguration` (`pulumi.Input[dict]`) - A `custom_https_configuration` block as defined below.
            * `azureKeyVaultCertificateSecretName` (`pulumi.Input[str]`) - The name of the Key Vault secret representing the full certificate PFX.
            * `azureKeyVaultCertificateSecretVersion` (`pulumi.Input[str]`) - The version of the Key Vault secret representing the full certificate PFX.
            * `azureKeyVaultCertificateVaultId` (`pulumi.Input[str]`) - The ID of the Key Vault containing the SSL certificate.
            * `certificateSource` (`pulumi.Input[str]`) - Certificate source to encrypted `HTTPS` traffic with. Allowed values are `FrontDoor` or `AzureKeyVault`. Defaults to `FrontDoor`.
            * `minimum_tls_version` (`pulumi.Input[str]`) - Minimum client TLS version supported.
            * `provisioningState` (`pulumi.Input[str]`) - Provisioning state of the Front Door.
            * `provisioningSubstate` (`pulumi.Input[str]`) - Provisioning substate of the Front Door

          * `customHttpsProvisioningEnabled` (`pulumi.Input[bool]`) - Should the HTTPS protocol be enabled for a custom domain associated with the Front Door?
          * `host_name` (`pulumi.Input[str]`) - Specifies the host name of the `frontend_endpoint`. Must be a domain name.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the `frontend_endpoint`.
          * `sessionAffinityEnabled` (`pulumi.Input[bool]`) - Whether to allow session affinity on this host. Valid options are `true` or `false` Defaults to `false`.
          * `sessionAffinityTtlSeconds` (`pulumi.Input[float]`) - The TTL to use in seconds for session affinity, if applicable. Defaults to `0`.
          * `webApplicationFirewallPolicyLinkId` (`pulumi.Input[str]`) - Defines the Web Application Firewall policy `ID` for each host.

        The **routing_rules** object supports the following:

          * `acceptedProtocols` (`pulumi.Input[list]`) - Protocol schemes to match for the Backend Routing Rule. Defaults to `Http`.
          * `enabled` (`pulumi.Input[bool]`) - `Enable` or `Disable` use of this Backend Routing Rule. Permitted values are `true` or `false`. Defaults to `true`.
          * `forwardingConfiguration` (`pulumi.Input[dict]`) - A `forwarding_configuration` block as defined below.
            * `backendPoolName` (`pulumi.Input[str]`) - Specifies the name of the Backend Pool to forward the incoming traffic to.
            * `cacheEnabled` (`pulumi.Input[bool]`) - Specifies whether to Enable caching or not. Valid options are `true` or `false`. Defaults to `false`.
            * `cacheQueryParameterStripDirective` (`pulumi.Input[str]`) - Defines cache behavior in releation to query string parameters. Valid options are `StripAll` or `StripNone`. Defaults to `StripAll`.
            * `cacheUseDynamicCompression` (`pulumi.Input[bool]`) - Whether to use dynamic compression when caching. Valid options are `true` or `false`. Defaults to `false`.
            * `customForwardingPath` (`pulumi.Input[str]`) - Path to use when constructing the request to forward to the backend. This functions as a URL Rewrite. Default behavior preserves the URL path.
            * `forwardingProtocol` (`pulumi.Input[str]`) - Protocol to use when redirecting. Valid options are `HttpOnly`, `HttpsOnly`, or `MatchRequest`. Defaults to `HttpsOnly`.

          * `frontend_endpoints` (`pulumi.Input[list]`) - The names of the `frontend_endpoint` blocks whithin this resource to associate with this `routing_rule`.
          * `id` (`pulumi.Input[str]`) - The ID of the FrontDoor.
          * `name` (`pulumi.Input[str]`) - Specifies the name of the Routing Rule.
          * `patternsToMatches` (`pulumi.Input[list]`) - The route patterns for the Backend Routing Rule. Defaults to `/*`.
          * `redirectConfiguration` (`pulumi.Input[dict]`) - A `redirect_configuration` block as defined below.
            * `customFragment` (`pulumi.Input[str]`) - The destination fragment in the portion of URL after '#'. Set this to add a fragment to the redirect URL.
            * `customHost` (`pulumi.Input[str]`) - Set this to change the URL for the redirection.
            * `customPath` (`pulumi.Input[str]`) - The path to retain as per the incoming request, or update in the URL for the redirection.
            * `customQueryString` (`pulumi.Input[str]`) - Replace any existing query string from the incoming request URL.
            * `redirectProtocol` (`pulumi.Input[str]`) - Protocol to use when redirecting. Valid options are `HttpOnly`, `HttpsOnly`, or `MatchRequest`. Defaults to `MatchRequest`
            * `redirectType` (`pulumi.Input[str]`) - Status code for the redirect. Valida options are `Moved`, `Found`, `TemporaryRedirect`, `PermanentRedirect`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["backend_pool_health_probes"] = backend_pool_health_probes
        __props__["backend_pool_load_balancings"] = backend_pool_load_balancings
        __props__["backend_pools"] = backend_pools
        __props__["backend_pools_send_receive_timeout_seconds"] = backend_pools_send_receive_timeout_seconds
        __props__["cname"] = cname
        __props__["enforce_backend_pools_certificate_name_check"] = enforce_backend_pools_certificate_name_check
        __props__["friendly_name"] = friendly_name
        __props__["frontend_endpoints"] = frontend_endpoints
        __props__["header_frontdoor_id"] = header_frontdoor_id
        __props__["load_balancer_enabled"] = load_balancer_enabled
        __props__["location"] = location
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["routing_rules"] = routing_rules
        __props__["tags"] = tags
        return Frontdoor(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class ServerSecurityAlertPolicy(pulumi.CustomResource):
    disabled_alerts: pulumi.Output[list]
    """
    Specifies an array of alerts that are disabled. Allowed values are: `Sql_Injection`, `Sql_Injection_Vulnerability`, `Access_Anomaly`, `Data_Exfiltration`, `Unsafe_Action`.
    """
    email_account_admins: pulumi.Output[bool]
    """
    Boolean flag which specifies if the alert is sent to the account administrators or not. Defaults to `false`.
    """
    email_addresses: pulumi.Output[list]
    """
    Specifies an array of e-mail addresses to which the alert is sent.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group that contains the MS SQL Server. Changing this forces a new resource to be created.
    """
    retention_days: pulumi.Output[float]
    """
    Specifies the number of days to keep in the Threat Detection audit logs. Defaults to `0`.
    """
    server_name: pulumi.Output[str]
    """
    Specifies the name of the MS SQL Server. Changing this forces a new resource to be created.
    """
    state: pulumi.Output[str]
    """
    Specifies the state of the policy, whether it is enabled or disabled or a policy has not been applied yet on the specific database server. Allowed values are: `Disabled`, `Enabled`.
    """
    storage_account_access_key: pulumi.Output[str]
    """
    Specifies the identifier key of the Threat Detection audit storage account.
    """
    storage_endpoint: pulumi.Output[str]
    """
    Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs.
    """
    def __init__(__self__, resource_name, opts=None, disabled_alerts=None, email_account_admins=None, email_addresses=None, resource_group_name=None, retention_days=None, server_name=None, state=None, storage_account_access_key=None, storage_endpoint=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Security Alert Policy for a MSSQL Server.

        > **NOTE** Security Alert Policy is currently only available for MS SQL databases.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West US")
        example_sql_server = azure.sql.SqlServer("exampleSqlServer",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            version="12.0",
            administrator_login="4dm1n157r470r",
            administrator_login_password="4-v3ry-53cr37-p455w0rd")
        example_account = azure.storage.Account("exampleAccount",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            account_tier="Standard",
            account_replication_type="GRS")
        example_server_security_alert_policy = azure.mssql.ServerSecurityAlertPolicy("exampleServerSecurityAlertPolicy",
            resource_group_name=example_resource_group.name,
            server_name=example_sql_server.name,
            state="Enabled",
            storage_endpoint=example_account.primary_blob_endpoint,
            storage_account_access_key=example_account.primary_access_key,
            disabled_alerts=[
                "Sql_Injection",
                "Data_Exfiltration",
            ],
            retention_days=20)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] disabled_alerts: Specifies an array of alerts that are disabled. Allowed values are: `Sql_Injection`, `Sql_Injection_Vulnerability`, `Access_Anomaly`, `Data_Exfiltration`, `Unsafe_Action`.
        :param pulumi.Input[bool] email_account_admins: Boolean flag which specifies if the alert is sent to the account administrators or not. Defaults to `false`.
        :param pulumi.Input[list] email_addresses: Specifies an array of e-mail addresses to which the alert is sent.
        :param pulumi.Input[str] resource_group_name: The name of the resource group that contains the MS SQL Server. Changing this forces a new resource to be created.
        :param pulumi.Input[float] retention_days: Specifies the number of days to keep in the Threat Detection audit logs. Defaults to `0`.
        :param pulumi.Input[str] server_name: Specifies the name of the MS SQL Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] state: Specifies the state of the policy, whether it is enabled or disabled or a policy has not been applied yet on the specific database server. Allowed values are: `Disabled`, `Enabled`.
        :param pulumi.Input[str] storage_account_access_key: Specifies the identifier key of the Threat Detection audit storage account.
        :param pulumi.Input[str] storage_endpoint: Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['disabled_alerts'] = disabled_alerts
            __props__['email_account_admins'] = email_account_admins
            __props__['email_addresses'] = email_addresses
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['retention_days'] = retention_days
            if server_name is None:
                raise TypeError("Missing required property 'server_name'")
            __props__['server_name'] = server_name
            if state is None:
                raise TypeError("Missing required property 'state'")
            __props__['state'] = state
            __props__['storage_account_access_key'] = storage_account_access_key
            __props__['storage_endpoint'] = storage_endpoint
        super(ServerSecurityAlertPolicy, __self__).__init__(
            'azure:mssql/serverSecurityAlertPolicy:ServerSecurityAlertPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, disabled_alerts=None, email_account_admins=None, email_addresses=None, resource_group_name=None, retention_days=None, server_name=None, state=None, storage_account_access_key=None, storage_endpoint=None):
        """
        Get an existing ServerSecurityAlertPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] disabled_alerts: Specifies an array of alerts that are disabled. Allowed values are: `Sql_Injection`, `Sql_Injection_Vulnerability`, `Access_Anomaly`, `Data_Exfiltration`, `Unsafe_Action`.
        :param pulumi.Input[bool] email_account_admins: Boolean flag which specifies if the alert is sent to the account administrators or not. Defaults to `false`.
        :param pulumi.Input[list] email_addresses: Specifies an array of e-mail addresses to which the alert is sent.
        :param pulumi.Input[str] resource_group_name: The name of the resource group that contains the MS SQL Server. Changing this forces a new resource to be created.
        :param pulumi.Input[float] retention_days: Specifies the number of days to keep in the Threat Detection audit logs. Defaults to `0`.
        :param pulumi.Input[str] server_name: Specifies the name of the MS SQL Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] state: Specifies the state of the policy, whether it is enabled or disabled or a policy has not been applied yet on the specific database server. Allowed values are: `Disabled`, `Enabled`.
        :param pulumi.Input[str] storage_account_access_key: Specifies the identifier key of the Threat Detection audit storage account.
        :param pulumi.Input[str] storage_endpoint: Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["disabled_alerts"] = disabled_alerts
        __props__["email_account_admins"] = email_account_admins
        __props__["email_addresses"] = email_addresses
        __props__["resource_group_name"] = resource_group_name
        __props__["retention_days"] = retention_days
        __props__["server_name"] = server_name
        __props__["state"] = state
        __props__["storage_account_access_key"] = storage_account_access_key
        __props__["storage_endpoint"] = storage_endpoint
        return ServerSecurityAlertPolicy(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class AutoscaleSetting(pulumi.CustomResource):
    enabled: pulumi.Output[bool]
    """
    Specifies whether automatic scaling is enabled for the target resource. Defaults to `true`.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the AutoScale Setting should exist. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the AutoScale Setting. Changing this forces a new resource to be created.
    """
    notification: pulumi.Output[dict]
    """
    Specifies a `notification` block as defined below.

      * `email` (`dict`) - A `email` block as defined below.
        * `customEmails` (`list`) - Specifies a list of custom email addresses to which the email notifications will be sent.
        * `sendToSubscriptionAdministrator` (`bool`) - Should email notifications be sent to the subscription administrator? Defaults to `false`.
        * `sendToSubscriptionCoAdministrator` (`bool`) - Should email notifications be sent to the subscription co-administrator? Defaults to `false`.

      * `webhooks` (`list`) - One or more `webhook` blocks as defined below.
        * `properties` (`dict`) - A map of settings.
        * `service_uri` (`str`) - The HTTPS URI which should receive scale notifications.
    """
    profiles: pulumi.Output[list]
    """
    Specifies one or more (up to 20) `profile` blocks as defined below.

      * `capacity` (`dict`) - A `capacity` block as defined below.
        * `default` (`float`) - The number of instances that are available for scaling if metrics are not available for evaluation. The default is only used if the current instance count is lower than the default. Valid values are between `0` and `1000`.
        * `maximum` (`float`) - The maximum number of instances for this resource. Valid values are between `0` and `1000`.
        * `minimum` (`float`) - The minimum number of instances for this resource. Valid values are between `0` and `1000`.

      * `fixedDate` (`dict`) - A `fixed_date` block as defined below. This cannot be specified if a `recurrence` block is specified.
        * `end` (`str`) - Specifies the end date for the profile, formatted as an RFC3339 date string.
        * `start` (`str`) - Specifies the start date for the profile, formatted as an RFC3339 date string.
        * `timezone` (`str`) - The Time Zone of the `start` and `end` times. A list of [possible values can be found here](https://msdn.microsoft.com/en-us/library/azure/dn931928.aspx). Defaults to `UTC`.

      * `name` (`str`) - Specifies the name of the profile.
      * `recurrence` (`dict`) - A `recurrence` block as defined below. This cannot be specified if a `fixed_date` block is specified.
        * `days` (`list`) - A list of days that this profile takes effect on. Possible values include `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`.
        * `hours` (`float`) - A list containing a single item, which specifies the Hour interval at which this recurrence should be triggered (in 24-hour time). Possible values are from `0` to `23`.
        * `minutes` (`float`) - A list containing a single item which specifies the Minute interval at which this recurrence should be triggered.
        * `timezone` (`str`) - The Time Zone used for the `hours` field. A list of [possible values can be found here](https://msdn.microsoft.com/en-us/library/azure/dn931928.aspx). Defaults to `UTC`.

      * `rules` (`list`) - One or more (up to 10) `rule` blocks as defined below.
        * `metricTrigger` (`dict`) - A `metric_trigger` block as defined below.
          * `metricName` (`str`) - The name of the metric that defines what the rule monitors, such as `Percentage CPU` for `Virtual Machine Scale Sets` and `CpuPercentage` for `App Service Plan`.
          * `metricResourceId` (`str`) - The ID of the Resource which the Rule monitors.
          * `operator` (`str`) - Specifies the operator used to compare the metric data and threshold. Possible values are: `Equals`, `NotEquals`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan`, `LessThanOrEqual`.
          * `statistic` (`str`) - Specifies how the metrics from multiple instances are combined. Possible values are `Average`, `Min` and `Max`.
          * `threshold` (`float`) - Specifies the threshold of the metric that triggers the scale action.
          * `timeAggregation` (`str`) - Specifies how the data that's collected should be combined over time. Possible values include `Average`, `Count`, `Maximum`, `Minimum`, `Last` and `Total`. Defaults to `Average`.
          * `timeGrain` (`str`) - Specifies the granularity of metrics that the rule monitors, which must be one of the pre-defined values returned from the metric definitions for the metric. This value must be between 1 minute and 12 hours an be formatted as an ISO 8601 string.
          * `time_window` (`str`) - Specifies the time range for which data is collected, which must be greater than the delay in metric collection (which varies from resource to resource). This value must be between 5 minutes and 12 hours and be formatted as an ISO 8601 string.

        * `scaleAction` (`dict`) - A `scale_action` block as defined below.
          * `cooldown` (`str`) - The amount of time to wait since the last scaling action before this action occurs. Must be between 1 minute and 1 week and formatted as a ISO 8601 string.
          * `direction` (`str`) - The scale direction. Possible values are `Increase` and `Decrease`.
          * `type` (`str`) - The type of action that should occur. Possible values are `ChangeCount`, `ExactCount` and `PercentChangeCount`.
          * `value` (`float`) - The number of instances involved in the scaling action. Defaults to `1`.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the Resource Group in the AutoScale Setting should be created. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    target_resource_id: pulumi.Output[str]
    """
    Specifies the resource ID of the resource that the autoscale setting should be added to.
    """
    def __init__(__self__, resource_name, opts=None, enabled=None, location=None, name=None, notification=None, profiles=None, resource_group_name=None, tags=None, target_resource_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a AutoScale Setting which can be applied to Virtual Machine Scale Sets, App Services and other scalable resources.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West US")
        example_scale_set = azure.compute.ScaleSet("exampleScaleSet")
        # ...
        example_autoscale_setting = azure.monitoring.AutoscaleSetting("exampleAutoscaleSetting",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            target_resource_id=example_scale_set.id,
            profiles=[{
                "name": "defaultProfile",
                "capacity": {
                    "default": 1,
                    "minimum": 1,
                    "maximum": 10,
                },
                "rules": [
                    {
                        "metricTrigger": {
                            "metricName": "Percentage CPU",
                            "metricResourceId": example_scale_set.id,
                            "timeGrain": "PT1M",
                            "statistic": "Average",
                            "time_window": "PT5M",
                            "timeAggregation": "Average",
                            "operator": "GreaterThan",
                            "threshold": 75,
                        },
                        "scaleAction": {
                            "direction": "Increase",
                            "type": "ChangeCount",
                            "value": "1",
                            "cooldown": "PT1M",
                        },
                    },
                    {
                        "metricTrigger": {
                            "metricName": "Percentage CPU",
                            "metricResourceId": example_scale_set.id,
                            "timeGrain": "PT1M",
                            "statistic": "Average",
                            "time_window": "PT5M",
                            "timeAggregation": "Average",
                            "operator": "LessThan",
                            "threshold": 25,
                        },
                        "scaleAction": {
                            "direction": "Decrease",
                            "type": "ChangeCount",
                            "value": "1",
                            "cooldown": "PT1M",
                        },
                    },
                ],
            }],
            notification={
                "email": {
                    "sendToSubscriptionAdministrator": True,
                    "sendToSubscriptionCoAdministrator": True,
                    "customEmails": ["admin@contoso.com"],
                },
            })
        ```
        ### Repeating On Weekends)

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West US")
        example_scale_set = azure.compute.ScaleSet("exampleScaleSet")
        # ...
        example_autoscale_setting = azure.monitoring.AutoscaleSetting("exampleAutoscaleSetting",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            target_resource_id=example_scale_set.id,
            profiles=[{
                "name": "Weekends",
                "capacity": {
                    "default": 1,
                    "minimum": 1,
                    "maximum": 10,
                },
                "rules": [
                    {
                        "metricTrigger": {
                            "metricName": "Percentage CPU",
                            "metricResourceId": example_scale_set.id,
                            "timeGrain": "PT1M",
                            "statistic": "Average",
                            "time_window": "PT5M",
                            "timeAggregation": "Average",
                            "operator": "GreaterThan",
                            "threshold": 90,
                        },
                        "scaleAction": {
                            "direction": "Increase",
                            "type": "ChangeCount",
                            "value": "2",
                            "cooldown": "PT1M",
                        },
                    },
                    {
                        "metricTrigger": {
                            "metricName": "Percentage CPU",
                            "metricResourceId": example_scale_set.id,
                            "timeGrain": "PT1M",
                            "statistic": "Average",
                            "time_window": "PT5M",
                            "timeAggregation": "Average",
                            "operator": "LessThan",
                            "threshold": 10,
                        },
                        "scaleAction": {
                            "direction": "Decrease",
                            "type": "ChangeCount",
                            "value": "2",
                            "cooldown": "PT1M",
                        },
                    },
                ],
                "recurrence": {
                    "frequency": "Week",
                    "timezone": "Pacific Standard Time",
                    "days": [
                        "Saturday",
                        "Sunday",
                    ],
                    "hours": [12],
                    "minutes": [0],
                },
            }],
            notification={
                "email": {
                    "sendToSubscriptionAdministrator": True,
                    "sendToSubscriptionCoAdministrator": True,
                    "customEmails": ["admin@contoso.com"],
                },
            })
        ```
        ### For Fixed Dates)

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West US")
        example_scale_set = azure.compute.ScaleSet("exampleScaleSet")
        # ...
        example_autoscale_setting = azure.monitoring.AutoscaleSetting("exampleAutoscaleSetting",
            enabled=True,
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            target_resource_id=example_scale_set.id,
            profiles=[{
                "name": "forJuly",
                "capacity": {
                    "default": 1,
                    "minimum": 1,
                    "maximum": 10,
                },
                "rules": [
                    {
                        "metricTrigger": {
                            "metricName": "Percentage CPU",
                            "metricResourceId": example_scale_set.id,
                            "timeGrain": "PT1M",
                            "statistic": "Average",
                            "time_window": "PT5M",
                            "timeAggregation": "Average",
                            "operator": "GreaterThan",
                            "threshold": 90,
                        },
                        "scaleAction": {
                            "direction": "Increase",
                            "type": "ChangeCount",
                            "value": "2",
                            "cooldown": "PT1M",
                        },
                    },
                    {
                        "metricTrigger": {
                            "metricName": "Percentage CPU",
                            "metricResourceId": example_scale_set.id,
                            "timeGrain": "PT1M",
                            "statistic": "Average",
                            "time_window": "PT5M",
                            "timeAggregation": "Average",
                            "operator": "LessThan",
                            "threshold": 10,
                        },
                        "scaleAction": {
                            "direction": "Decrease",
                            "type": "ChangeCount",
                            "value": "2",
                            "cooldown": "PT1M",
                        },
                    },
                ],
                "fixedDate": {
                    "timezone": "Pacific Standard Time",
                    "start": "2020-07-01T00:00:00Z",
                    "end": "2020-07-31T23:59:59Z",
                },
            }],
            notification={
                "email": {
                    "sendToSubscriptionAdministrator": True,
                    "sendToSubscriptionCoAdministrator": True,
                    "customEmails": ["admin@contoso.com"],
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: Specifies whether automatic scaling is enabled for the target resource. Defaults to `true`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the AutoScale Setting should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the AutoScale Setting. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] notification: Specifies a `notification` block as defined below.
        :param pulumi.Input[list] profiles: Specifies one or more (up to 20) `profile` blocks as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in the AutoScale Setting should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] target_resource_id: Specifies the resource ID of the resource that the autoscale setting should be added to.

        The **notification** object supports the following:

          * `email` (`pulumi.Input[dict]`) - A `email` block as defined below.
            * `customEmails` (`pulumi.Input[list]`) - Specifies a list of custom email addresses to which the email notifications will be sent.
            * `sendToSubscriptionAdministrator` (`pulumi.Input[bool]`) - Should email notifications be sent to the subscription administrator? Defaults to `false`.
            * `sendToSubscriptionCoAdministrator` (`pulumi.Input[bool]`) - Should email notifications be sent to the subscription co-administrator? Defaults to `false`.

          * `webhooks` (`pulumi.Input[list]`) - One or more `webhook` blocks as defined below.
            * `properties` (`pulumi.Input[dict]`) - A map of settings.
            * `service_uri` (`pulumi.Input[str]`) - The HTTPS URI which should receive scale notifications.

        The **profiles** object supports the following:

          * `capacity` (`pulumi.Input[dict]`) - A `capacity` block as defined below.
            * `default` (`pulumi.Input[float]`) - The number of instances that are available for scaling if metrics are not available for evaluation. The default is only used if the current instance count is lower than the default. Valid values are between `0` and `1000`.
            * `maximum` (`pulumi.Input[float]`) - The maximum number of instances for this resource. Valid values are between `0` and `1000`.
            * `minimum` (`pulumi.Input[float]`) - The minimum number of instances for this resource. Valid values are between `0` and `1000`.

          * `fixedDate` (`pulumi.Input[dict]`) - A `fixed_date` block as defined below. This cannot be specified if a `recurrence` block is specified.
            * `end` (`pulumi.Input[str]`) - Specifies the end date for the profile, formatted as an RFC3339 date string.
            * `start` (`pulumi.Input[str]`) - Specifies the start date for the profile, formatted as an RFC3339 date string.
            * `timezone` (`pulumi.Input[str]`) - The Time Zone of the `start` and `end` times. A list of [possible values can be found here](https://msdn.microsoft.com/en-us/library/azure/dn931928.aspx). Defaults to `UTC`.

          * `name` (`pulumi.Input[str]`) - Specifies the name of the profile.
          * `recurrence` (`pulumi.Input[dict]`) - A `recurrence` block as defined below. This cannot be specified if a `fixed_date` block is specified.
            * `days` (`pulumi.Input[list]`) - A list of days that this profile takes effect on. Possible values include `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`.
            * `hours` (`pulumi.Input[float]`) - A list containing a single item, which specifies the Hour interval at which this recurrence should be triggered (in 24-hour time). Possible values are from `0` to `23`.
            * `minutes` (`pulumi.Input[float]`) - A list containing a single item which specifies the Minute interval at which this recurrence should be triggered.
            * `timezone` (`pulumi.Input[str]`) - The Time Zone used for the `hours` field. A list of [possible values can be found here](https://msdn.microsoft.com/en-us/library/azure/dn931928.aspx). Defaults to `UTC`.

          * `rules` (`pulumi.Input[list]`) - One or more (up to 10) `rule` blocks as defined below.
            * `metricTrigger` (`pulumi.Input[dict]`) - A `metric_trigger` block as defined below.
              * `metricName` (`pulumi.Input[str]`) - The name of the metric that defines what the rule monitors, such as `Percentage CPU` for `Virtual Machine Scale Sets` and `CpuPercentage` for `App Service Plan`.
              * `metricResourceId` (`pulumi.Input[str]`) - The ID of the Resource which the Rule monitors.
              * `operator` (`pulumi.Input[str]`) - Specifies the operator used to compare the metric data and threshold. Possible values are: `Equals`, `NotEquals`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan`, `LessThanOrEqual`.
              * `statistic` (`pulumi.Input[str]`) - Specifies how the metrics from multiple instances are combined. Possible values are `Average`, `Min` and `Max`.
              * `threshold` (`pulumi.Input[float]`) - Specifies the threshold of the metric that triggers the scale action.
              * `timeAggregation` (`pulumi.Input[str]`) - Specifies how the data that's collected should be combined over time. Possible values include `Average`, `Count`, `Maximum`, `Minimum`, `Last` and `Total`. Defaults to `Average`.
              * `timeGrain` (`pulumi.Input[str]`) - Specifies the granularity of metrics that the rule monitors, which must be one of the pre-defined values returned from the metric definitions for the metric. This value must be between 1 minute and 12 hours an be formatted as an ISO 8601 string.
              * `time_window` (`pulumi.Input[str]`) - Specifies the time range for which data is collected, which must be greater than the delay in metric collection (which varies from resource to resource). This value must be between 5 minutes and 12 hours and be formatted as an ISO 8601 string.

            * `scaleAction` (`pulumi.Input[dict]`) - A `scale_action` block as defined below.
              * `cooldown` (`pulumi.Input[str]`) - The amount of time to wait since the last scaling action before this action occurs. Must be between 1 minute and 1 week and formatted as a ISO 8601 string.
              * `direction` (`pulumi.Input[str]`) - The scale direction. Possible values are `Increase` and `Decrease`.
              * `type` (`pulumi.Input[str]`) - The type of action that should occur. Possible values are `ChangeCount`, `ExactCount` and `PercentChangeCount`.
              * `value` (`pulumi.Input[float]`) - The number of instances involved in the scaling action. Defaults to `1`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['enabled'] = enabled
            __props__['location'] = location
            __props__['name'] = name
            __props__['notification'] = notification
            if profiles is None:
                raise TypeError("Missing required property 'profiles'")
            __props__['profiles'] = profiles
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
            if target_resource_id is None:
                raise TypeError("Missing required property 'target_resource_id'")
            __props__['target_resource_id'] = target_resource_id
        super(AutoscaleSetting, __self__).__init__(
            'azure:monitoring/autoscaleSetting:AutoscaleSetting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, enabled=None, location=None, name=None, notification=None, profiles=None, resource_group_name=None, tags=None, target_resource_id=None):
        """
        Get an existing AutoscaleSetting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: Specifies whether automatic scaling is enabled for the target resource. Defaults to `true`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the AutoScale Setting should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the AutoScale Setting. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] notification: Specifies a `notification` block as defined below.
        :param pulumi.Input[list] profiles: Specifies one or more (up to 20) `profile` blocks as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in the AutoScale Setting should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] target_resource_id: Specifies the resource ID of the resource that the autoscale setting should be added to.

        The **notification** object supports the following:

          * `email` (`pulumi.Input[dict]`) - A `email` block as defined below.
            * `customEmails` (`pulumi.Input[list]`) - Specifies a list of custom email addresses to which the email notifications will be sent.
            * `sendToSubscriptionAdministrator` (`pulumi.Input[bool]`) - Should email notifications be sent to the subscription administrator? Defaults to `false`.
            * `sendToSubscriptionCoAdministrator` (`pulumi.Input[bool]`) - Should email notifications be sent to the subscription co-administrator? Defaults to `false`.

          * `webhooks` (`pulumi.Input[list]`) - One or more `webhook` blocks as defined below.
            * `properties` (`pulumi.Input[dict]`) - A map of settings.
            * `service_uri` (`pulumi.Input[str]`) - The HTTPS URI which should receive scale notifications.

        The **profiles** object supports the following:

          * `capacity` (`pulumi.Input[dict]`) - A `capacity` block as defined below.
            * `default` (`pulumi.Input[float]`) - The number of instances that are available for scaling if metrics are not available for evaluation. The default is only used if the current instance count is lower than the default. Valid values are between `0` and `1000`.
            * `maximum` (`pulumi.Input[float]`) - The maximum number of instances for this resource. Valid values are between `0` and `1000`.
            * `minimum` (`pulumi.Input[float]`) - The minimum number of instances for this resource. Valid values are between `0` and `1000`.

          * `fixedDate` (`pulumi.Input[dict]`) - A `fixed_date` block as defined below. This cannot be specified if a `recurrence` block is specified.
            * `end` (`pulumi.Input[str]`) - Specifies the end date for the profile, formatted as an RFC3339 date string.
            * `start` (`pulumi.Input[str]`) - Specifies the start date for the profile, formatted as an RFC3339 date string.
            * `timezone` (`pulumi.Input[str]`) - The Time Zone of the `start` and `end` times. A list of [possible values can be found here](https://msdn.microsoft.com/en-us/library/azure/dn931928.aspx). Defaults to `UTC`.

          * `name` (`pulumi.Input[str]`) - Specifies the name of the profile.
          * `recurrence` (`pulumi.Input[dict]`) - A `recurrence` block as defined below. This cannot be specified if a `fixed_date` block is specified.
            * `days` (`pulumi.Input[list]`) - A list of days that this profile takes effect on. Possible values include `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`.
            * `hours` (`pulumi.Input[float]`) - A list containing a single item, which specifies the Hour interval at which this recurrence should be triggered (in 24-hour time). Possible values are from `0` to `23`.
            * `minutes` (`pulumi.Input[float]`) - A list containing a single item which specifies the Minute interval at which this recurrence should be triggered.
            * `timezone` (`pulumi.Input[str]`) - The Time Zone used for the `hours` field. A list of [possible values can be found here](https://msdn.microsoft.com/en-us/library/azure/dn931928.aspx). Defaults to `UTC`.

          * `rules` (`pulumi.Input[list]`) - One or more (up to 10) `rule` blocks as defined below.
            * `metricTrigger` (`pulumi.Input[dict]`) - A `metric_trigger` block as defined below.
              * `metricName` (`pulumi.Input[str]`) - The name of the metric that defines what the rule monitors, such as `Percentage CPU` for `Virtual Machine Scale Sets` and `CpuPercentage` for `App Service Plan`.
              * `metricResourceId` (`pulumi.Input[str]`) - The ID of the Resource which the Rule monitors.
              * `operator` (`pulumi.Input[str]`) - Specifies the operator used to compare the metric data and threshold. Possible values are: `Equals`, `NotEquals`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan`, `LessThanOrEqual`.
              * `statistic` (`pulumi.Input[str]`) - Specifies how the metrics from multiple instances are combined. Possible values are `Average`, `Min` and `Max`.
              * `threshold` (`pulumi.Input[float]`) - Specifies the threshold of the metric that triggers the scale action.
              * `timeAggregation` (`pulumi.Input[str]`) - Specifies how the data that's collected should be combined over time. Possible values include `Average`, `Count`, `Maximum`, `Minimum`, `Last` and `Total`. Defaults to `Average`.
              * `timeGrain` (`pulumi.Input[str]`) - Specifies the granularity of metrics that the rule monitors, which must be one of the pre-defined values returned from the metric definitions for the metric. This value must be between 1 minute and 12 hours an be formatted as an ISO 8601 string.
              * `time_window` (`pulumi.Input[str]`) - Specifies the time range for which data is collected, which must be greater than the delay in metric collection (which varies from resource to resource). This value must be between 5 minutes and 12 hours and be formatted as an ISO 8601 string.

            * `scaleAction` (`pulumi.Input[dict]`) - A `scale_action` block as defined below.
              * `cooldown` (`pulumi.Input[str]`) - The amount of time to wait since the last scaling action before this action occurs. Must be between 1 minute and 1 week and formatted as a ISO 8601 string.
              * `direction` (`pulumi.Input[str]`) - The scale direction. Possible values are `Increase` and `Decrease`.
              * `type` (`pulumi.Input[str]`) - The type of action that should occur. Possible values are `ChangeCount`, `ExactCount` and `PercentChangeCount`.
              * `value` (`pulumi.Input[float]`) - The number of instances involved in the scaling action. Defaults to `1`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["enabled"] = enabled
        __props__["location"] = location
        __props__["name"] = name
        __props__["notification"] = notification
        __props__["profiles"] = profiles
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        __props__["target_resource_id"] = target_resource_id
        return AutoscaleSetting(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
